
# Hdl21 PDKs

Built-in `hdl21.pdk` plug-ins.

- [Sky130](./Sky130) serves the [SkyWater 130nm](https://github.com/google/skywater-pdk) technology
- [Gf180](./Gf180/) serves the [Global Foundries 180nm MCU](https://github.com/gf180mcu-pdk) technology
- [Asap7](./Asap7) serves the [ASAP7](https://github.com/The-OpenROAD-Project/asap7/) predictive/ academic technology

While source-controlled in the Hdl21 codebase, each are stand-alone packages distributed through PyPi. 

An additional fully-fictitious `sample_pdk`, available in the `hdl21` namespace at `hdl21.pdk.sample_pdk`, makes an even lighter-weight demonstration of a PDK plug-in. 